/*
 * VCNL36826S_Application_Library.h
 *
 * Created  : 13 April 2021
 * Modified : 6 May 2021
 * Author   : HWanyusof
 * Version	: 1.0
 */

#include "typedefinition.h"

/*Get Proximity Mode
 *returns the PS mode status of the sensor as follows:
 *
 * 0 - PS Shutdown Mode
 * 1 - Auto/Self-Timed Mode
 * 2 - Active Force Mode/Continuous Forced Mode
 * 3 - Low Power Mode
 * 4 - Auto Calibration Mode
 *
 */
int VCNL36826S_GET_PS_Mode();

/*Get delay for auto calibration mode
 *This delay depends on the AC_Period and Auto Calibration Number of Measurement
 *For Example PS_AC_PERIOD = 3ms and PS_AC_NUM = 8 -> (3ms * 8) + tolorance ≈ 30ms
 *returns the delay as PS_AC_PERIOD * PS_AC_NUM + 6ms tolerance
 *
 */
int VCNL36826S_GET_DELAY_PS_AC();

//Print Auto Calibration Interrupt status
void Print_PS_AC_INT_STATUS();

//Reset the Sensor to the default value
void Reset_Sensor();

/*Print all of the Register Value
 *Print_All()
 *
 */
void Print_All();

//Print the output of the Auto Mode/Self-Timed Mode
void Print_Auto_Mode();

//Print the output of the Active Force Mode/Continuous Forced Mode
void Print_AF_Mode();

//Print the output of the Low Power Mode
void Print_Low_Power_Mode();

//Print the output of the Auto Calibration Mode
void Print_Auto_Calibration_Mode();

//Print the Register Value
void Print_Register_Settings();

/*Print the variable in DEC for debugging
 *Print_Variable_DEC(Word Var)
 *Word Var - Input Parameter:
 *
 * Value between 0d0 and 0d65535
 */
void Print_Variable_DEC(Word Var);

/*Print the variable in HEX for debugging
 *Print_Variable_HEX(Word Var)
 *Word Var - Input Parameter:
 *
 * Value between 0d0 and 0d65535
 */
void Print_Variable_HEX(Word Var);

/*Reverses a string 'str' of length 'len'
 *reverse(char* str, int len)
 *char* str - Array pointer to be reversed
 *int len - Length of the array
 */
void reverse(char* str, int len);

/*Converts a given integer x to string str[].
 *intToStr(int x, char str[], int d)
 *int x - floating-point number to be converted to a string (Both the integer part as well as fraction/decimal point part)
 *char str[] - output string of the floating-point number in the form of array character
 *int d - number of decimal point (the integer part always = 0, the fraction/decimal point part = int afterpoint from ftoa() input)
 */
int intToStr(int x, char str[], int d);

/*Converts a floating-point/double number to string.
 *ftoa(float n, char* res, int afterpoint)
 *float n - floating-point number to be converted to a string
 *char* res - pointer to output string of the floating-point number in the form of array character
 *int d - number of decimal point
 */
void ftoa(float n, char* res, int afterpoint);
